@@ -19,9 +19,9 @@ class MessageHandler(UpdateHandler):
         await self.reply(text, self.reply_markup)
 
     async def reply(
-        self,
-        text: str,
-        markup: ReplyMarkup | None = None,
+            self,
+            text: str,
+            markup: ReplyMarkup | None = None,
     ) -> telegram.Message:
         return await self.message.reply(text, markup)
 
@@ -36,3 +36,7 @@ class MessageHandler(UpdateHandler):
     @property
     def user(self) -> User:
         return self.message.user
+
+    @property
+    def text(self) -> str:
+        return self.message.text
