@@ -16,9 +16,9 @@ class Message(TelegramObject):
         super().__init__(raw)
 
     async def reply(
-        self,
-        text: str,
-        markup: ReplyMarkup | None = None,
+            self,
+            text: str,
+            markup: ReplyMarkup | None = None,
     ) -> telegram.Message:
         markup = cast(ReplyMarkup, markup)  # fix PTB error
         return await self.raw.reply_text(text, reply_markup=markup)
@@ -31,3 +31,7 @@ class Message(TelegramObject):
     @property
     def chat(self) -> Chat:
         return Chat(self.raw.chat)
+
+    @property
+    def text(self) -> str:
+        return self.get_validated_field("text", self.raw.text)
